Spectral Cross-Correlation
==========================
Cross-correlation is frequently used to measure redshift by comparing a
measured spectrum to a template.  `The Sloan survey made use of this technique
<http://www.sdss.org/dr5/algorithms/redshift_type.html#xcorz>`_.

However, the "standard" approach to determining errors 


http://www.sdss.org/dr5/algorithms/spectemplates/spDR2-028.fit
